Module corn_cli::error

source ·

Enums

Traits

Functions

Pretty prints a parser error, indicating where in the corn-cli source code the error occurred and the rules the parser expected in that position.
Pretty-prints message to stderr. If context is supplied, it will be appended to the first line.