pub fn format_parser_err(error: Error<Rule>, file: String, path: &Path) -> String
Pretty prints a parser error, indicating where in the corn-cli source code the error occurred and the rules the parser expected in that position.

The output is designed to mimic the Rust compiler output.